use r2d2_sqlite::rusqlite::{self, Row};
use serde::{Deserialize, Serialize};

use super::{DbError, DbPool};

#[derive(Serialize, Deserialize)]
pub struct Comment {
    id: i32,
    plant_id: i32,
    comment: String,
}

#[derive(Deserialize)]
pub struct NewComment {
    plant_id: i32,
    comment: String,
}

impl Comment {
    pub fn from_row(row: &Row<'_>) -> Result<Self, rusqlite::Error> {
        Ok(Self {
            id: row.get(0)?,
            plant_id: row.get(1)?,
            comment: row.get(2)?,
        })
    }
}

impl NewComment {
    pub fn insert(self, pool: &DbPool) -> Result<Comment, DbError> {
        let conn = pool.get()?;

        let mut stmt =
            conn.prepare("insert into comments (plant_id, comment) values ($1, $2) returning *")?;
        Ok(stmt.query_row((self.plant_id, self.comment), Comment::from_row)?)
    }
}
